bayespy.inference.vmp.nodes.binomial.BinomialMoments
====================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. autoclass:: BinomialMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~BinomialMoments.__init__
      ~BinomialMoments.add_converter
      ~BinomialMoments.compute_dims_from_values
      ~BinomialMoments.compute_fixed_moments
      ~BinomialMoments.get_converter
   
   

   
   
   